# Sentinel-1
GRD_HD = 'GRD-HD'
GRD_MD = 'GRD-MD'
GRD_MS = 'GRD-MS'
GRD_HS = 'GRD-HS'
SLC = 'SLC'
OCN = 'OCN'
RAW = 'RAW'
METADATA_GRD_HD = 'METADATA_GRD-HD'
METADATA_GRD_MD = 'METADATA_GRD-MD'
METADATA_GRD_MS = 'METADATA_GRD-MS'
METADATA_GRD_HS = 'METADATA_GRD-HS'
METADATA_SLC = 'METADATA_SLC'
METADATA_OCN = 'METADATA_OCN'
METADATA_RAW = 'METADATA_RAW'

# ALOS PALSAR
L1_0 = 'L1.0'
L1_1 = 'L1.1'
L1_5 = 'L1.5'
L2_2 = 'L2.2'
RTC_LOW_RES = 'RTC_LOW_RES'
RTC_HIGH_RES = 'RTC_HI_RES'
KMZ = 'KMZ'

# ALOS AVNIR
# No PROCESSING_TYPE attribute in CMR

# SIR-C
# SLC and SLC metadata are both 'SLC', provided by Sentinel-1 constants

# Sentinel-1 InSAR
GUNW_STD = 'GUNW_STD'
GUNW_AMP = 'GUNW_AMP'
GUNW_CON = 'GUNW_CON'
GUN_COH = 'GUNW_COH'
GUNW_UNW = 'GUNW_UNW'

# SMAP
L1A_RADAR_RO_HDF5 = 'L1A_Radar_RO_HDF5'
L1A_RADAR_HDF5 = 'L1A_Radar_HDF5'
L1B_S0_LOW_RES_HDF5 = 'L1B_S0_LoRes_HDF5'
L1C_S0_HIGH_RES_HDF5 = 'L1C_S0_HiRes_HDF5'
L1A_RADAR_RO_QA = 'L1A_Radar_RO_QA'
L1A_RADAR_QA = 'L1A_Radar_QA'
L1B_S0_LOW_RES_QA = 'L1B_S0_LoRes_QA'
L1C_S0_HIGH_RES_QA = 'L1C_S0_HiRes_QA'
L1A_RADAR_RO_ISO_XML = 'L1A_Radar_RO_ISO_XML'
L1B_S0_LOW_RES_ISO_XML = 'L1B_S0_LoRes_ISO_XML'
L1C_S0_HIGH_RES_ISO_XML = 'L1C_S0_HiRes_ISO_XML'

# UAVSAR
AMPLITUDE = 'AMPLITUDE'
STOKES = 'STOKES'
AMPLITUDE_GRD = 'AMPLITUDE_GRD'
PROJECTED = 'PROJECTED'
PROJECTED_ML5X5 = 'PROJECTED_ML5X5'
INTERFEROMETRY_GRD = 'INTERFEROMETRY_GRD'
INTERFEROMETRY = 'INTERFEROMETRY'
COMPLEX = 'COMPLEX'
# KMZ provided by ALOS PALSAR
INC = 'INC'
SLOPE = 'SLOPE'
DEM_TIFF = 'DEM_TIFF'
PAULI = 'PAULI'
METADATA = 'METADATA'

# RADARSAT
L0 = 'L0'
L1 = 'L1'

#ERS
# L0 provided by RADARSAT
# L1 provided by RADARSAT

# JERS
# L0 provided by RADARSAT
# L1 provided by RADARSAT

# AIRSAR
CTIF = 'CTIF'
PTIF = 'PTIF'
LTIF = 'LTIF'
JPG = 'JPG'
LSTOKES = 'LSTOKES'
PSTOKES = 'PSTOKES'
CSTOKES = 'CSTOKES'
DEM = 'DEM'

# SEASAT
GEOTIFF = 'GEOTIFF'
# L1 provided by RADARSAT
